@@ -1,6 +1,6 @@
 ;;; ef-maris-light-theme.el --- Legible light theme with blue, cyan, and green colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -108,17 +108,18 @@
     (bg-hover-secondary "#b7bbea")
     (bg-hl-line "#dae5f0")
     (bg-paren-match "#cab3b2")
-    (bg-region "#c8dcff")
     (bg-err "#f2c2b5") ; check with err
     (bg-warning "#e8df9a") ; check with warning
     (bg-info "#a4e2cf") ; check with info
+    (bg-region "#c8dcff")))
 
-    (err red-warmer)
+(defconst ef-maris-light-palette-mappings-partial
+  '((err red-warmer)
     (warning yellow-warmer)
     (info green-cooler)
 
     (fg-link blue)
-    (fg-link-alt magenta-cooler)
+    (fg-link-visited magenta-cooler)
     (name blue)
     (keybind blue-cooler)
     (identifier magenta-faint)
@@ -136,7 +137,7 @@
     (type green)
     (variable cyan)
     (variable-use cyan-faint)
-    (rx-escape yellow) ; compare with `string'
+    (rx-backslash yellow) ; compare with `string'
     (rx-construct red)
 
     (accent-0 blue-cooler)
@@ -156,16 +157,16 @@
     (date-weekday cyan-warmer)
     (date-weekend red-faint)
 
-    (prose-code cyan)
+    (fg-prose-code cyan)
     (prose-done green-cooler)
-    (prose-macro magenta-cooler)
+    (fg-prose-macro magenta-cooler)
     (prose-metadata fg-dim)
     (prose-metadata-value fg-alt)
     (prose-table fg-alt)
     (prose-table-formula warning)
     (prose-tag cyan-faint)
     (prose-todo red-cooler)
-    (prose-verbatim green-warmer)
+    (fg-prose-verbatim green-warmer)
 
     (mail-cite-0 cyan)
     (mail-cite-1 magenta)
@@ -196,8 +197,7 @@
     (rainbow-5 blue-cooler)
     (rainbow-6 magenta)
     (rainbow-7 cyan-cooler)
-    (rainbow-8 yellow-cooler))
-  "Legible light marine theme with blue, cyan, and green colors.")
+    (rainbow-8 yellow-cooler)))
 
 (defcustom ef-maris-light-palette-overrides nil
   "Overrides for `ef-maris-light-palette'.
@@ -217,15 +217,19 @@ further details)."
   :link '(info-link "(ef-themes) Palette overrides"))
 
 (defconst ef-maris-light-palette
-  (append ef-themes-common-palette-overrides ef-maris-light-palette-partial ef-themes-palette-common))
+  (modus-themes-generate-palette
+   ef-maris-light-palette-partial
+   nil
+   nil
+   (append ef-maris-light-palette-mappings-partial ef-themes-palette-common)))
 
 (modus-themes-theme
  'ef-maris-light
  'ef-themes
  "Legible light marine theme with blue, cyan, and green colors."
  'light
- 'modus-operandi-palette
  'ef-maris-light-palette
+ nil
  'ef-maris-light-palette-overrides
  'ef-themes-custom-faces)
 
