@@ -1,6 +1,6 @@
 ;;; ef-trio-dark-theme.el --- Legible dark theme with magenta, blue, teal colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -108,17 +108,18 @@
     (bg-hover-secondary "#452f5f")
     (bg-hl-line "#34223f")
     (bg-paren-match "#2f605e")
-    (bg-region "#16304f")
     (bg-err "#461018") ; check with err
     (bg-warning "#3a330f") ; check with warning
     (bg-info "#103515") ; check with info
+    (bg-region "#16304f")))
 
-    (err red-warmer)
+(defconst ef-trio-dark-palette-mappings-partial
+  '((err red-warmer)
     (warning yellow)
     (info green)
 
-    (link cyan)
-    (link-alt green-warmer)
+    (fg-link cyan)
+    (fg-link-visited green-warmer)
     (name blue)
     (keybind magenta-warmer)
     (identifier red-faint)
@@ -136,7 +137,7 @@
     (type cyan-cooler)
     (variable cyan-warmer)
     (variable-use cyan-faint)
-    (rx-escape blue-warmer) ; compare with `string'
+    (rx-backslash blue-warmer) ; compare with `string'
     (rx-construct red)
 
     (accent-0 magenta-warmer)
@@ -156,16 +157,16 @@
     (date-weekday cyan)
     (date-weekend red-faint)
 
-    (prose-code green-cooler)
+    (fg-prose-code green-cooler)
     (prose-done green)
-    (prose-macro blue-warmer)
+    (fg-prose-macro blue-warmer)
     (prose-metadata fg-dim)
     (prose-metadata-value fg-alt)
     (prose-table fg-alt)
     (prose-table-formula err)
     (prose-tag magenta-faint)
     (prose-todo red-warmer)
-    (prose-verbatim magenta-warmer)
+    (fg-prose-verbatim magenta-warmer)
 
     (mail-cite-0 blue-warmer)
     (mail-cite-1 magenta-warmer)
@@ -196,8 +197,7 @@
     (rainbow-5 green-warmer)
     (rainbow-6 magenta-cooler)
     (rainbow-7 cyan-warmer)
-    (rainbow-8 yellow-cooler))
-  "Legible dark purple grey theme with magenta, blue, teal colors.")
+    (rainbow-8 yellow-cooler)))
 
 (defcustom ef-trio-dark-palette-overrides nil
   "Overrides for `ef-trio-dark-palette'.
@@ -217,15 +217,19 @@ further details)."
   :link '(info-link "(ef-themes) Palette overrides"))
 
 (defconst ef-trio-dark-palette
-  (append ef-themes-common-palette-overrides ef-trio-dark-palette-partial ef-themes-palette-common))
+  (modus-themes-generate-palette
+   ef-trio-dark-palette-partial
+   nil
+   nil
+   (append ef-trio-dark-palette-mappings-partial ef-themes-palette-common)))
 
 (modus-themes-theme
  'ef-trio-dark
  'ef-themes
  "Legible dark purple grey theme with magenta, blue, teal colors."
  'dark
- 'modus-vivendi-palette
  'ef-trio-dark-palette
+ nil
  'ef-trio-dark-palette-overrides
  'ef-themes-custom-faces)
 
